@@ -300,9 +300,13 @@ allocate_notifies_desired_index (RealDispatch *d)
     {
       unsigned new_size = d->notifies_desired_alloced * 2;
       ProtobufC_FDNotify *n = ALLOC (new_size * sizeof (ProtobufC_FDNotify));
+      Callback *c = ALLOC (new_size * sizeof (Callback));
       memcpy (n, d->base.notifies_desired, d->notifies_desired_alloced * sizeof (ProtobufC_FDNotify));
       FREE (d->base.notifies_desired);
+      memcpy (c, d->callbacks, d->notifies_desired_alloced * sizeof (Callback));
+      FREE (d->callbacks);
       d->base.notifies_desired = n;
+      d->callbacks = c;
       d->notifies_desired_alloced = new_size;
     }
 #if DEBUG_DISPATCH_INTERNALS
@@ -373,6 +377,7 @@ deallocate_change_index (RealDispatch *d,
   unsigned ch_ind = fm->change_index;
   unsigned from = d->base.n_changes - 1;
   ProtobufC_FD from_fd;
+  fm->change_index = -1;
   if (ch_ind == from)
     {
       d->base.n_changes--;
@@ -405,6 +410,7 @@ deallocate_notify_desired_index (RealDispatch *d,
   from_fd = d->base.notifies_desired[from].fd;
   get_fd_map (d, from_fd)->notify_desired_index = nd_ind;
   d->base.notifies_desired[nd_ind] = d->base.notifies_desired[from];
+  d->callbacks[nd_ind] = d->callbacks[from];
   d->base.n_notifies_desired--;
 }
 
