@@ -448,8 +448,8 @@ uint32_to_le (uint32_t le)
   return le;
 #else
   return (le << 24) | (le >> 24)
-       | ((le >> 8) & 0xff0000)
-       | ((le << 8) & 0xff00);
+       | ((le >> 8) & 0xff00)
+       | ((le << 8) & 0xff0000);
 #endif
 }
 #define uint32_from_le uint32_to_le             /* make the code more readable, i guess */
@@ -777,6 +777,17 @@ protobuf_c_rpc_client_set_autoreconnect_period (ProtobufC_RPC_Client *client,
   client->autoreconnect = 1;
   client->autoreconnect_millis = millis;
 }
+
+
+void
+protobuf_c_rpc_client_set_error_handler (ProtobufC_RPC_Client *client,
+                                         ProtobufC_RPC_Error_Func func,
+                                         void                    *func_data)
+{
+  client->error_handler = func;
+  client->error_handler_data = func_data;
+}
+
 void
 protobuf_c_rpc_client_disable_autoreconnect (ProtobufC_RPC_Client *client)
 {
@@ -1343,3 +1354,12 @@ protobuf_c_rpc_server_destroy (ProtobufC_RPC_Server *server,
 
   return rv;
 }
+
+void
+protobuf_c_rpc_server_set_error_handler (ProtobufC_RPC_Server *server,
+                                         ProtobufC_RPC_Error_Func func,
+                                         void                 *error_func_data)
+{
+  server->error_handler = func;
+  server->error_handler_data = error_func_data;
+}
