@@ -752,6 +752,178 @@ static void dump_test_repeated_SubMess (void)
   mess.add_test_message()->set_test(667);
   dump_message_bytes(&mess, "test_repeated_submess_1");
 }
+#undef DUMP_STATIC_ARRAY_GENERIC
+
+#define DUMP_STATIC_ARRAY_GENERIC(member, static_array, output_array_name) \
+  do{ \
+    TestMessPacked mess; \
+    for (unsigned i = 0; i < N_ELEMENTS (static_array); i++) \
+      mess.add_##member(static_array[i]); \
+    dump_message_bytes(&mess, output_array_name); \
+  }while(0)
+static void dump_test_packed_repeated_int32 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_int32, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int32_arr0, "test_packed_repeated_int32_arr0");
+  DUMP_STATIC_ARRAY (int32_arr1, "test_packed_repeated_int32_arr1");
+  DUMP_STATIC_ARRAY (int32_arr_min_max, "test_packed_repeated_int32_arr_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_sint32 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_sint32, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int32_arr0, "test_packed_repeated_sint32_arr0");
+  DUMP_STATIC_ARRAY (int32_arr1, "test_packed_repeated_sint32_arr1");
+  DUMP_STATIC_ARRAY (int32_arr_min_max, "test_packed_repeated_sint32_arr_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_uint32 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_uint32, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (uint32_roundnumbers, "test_packed_repeated_uint32_roundnumbers");
+  DUMP_STATIC_ARRAY (uint32_0_max, "test_packed_repeated_uint32_0_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_sfixed32 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_sfixed32, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int32_arr0, "test_packed_repeated_sfixed32_arr0");
+  DUMP_STATIC_ARRAY (int32_arr1, "test_packed_repeated_sfixed32_arr1");
+  DUMP_STATIC_ARRAY (int32_arr_min_max, "test_packed_repeated_sfixed32_arr_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_fixed32 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_fixed32, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (uint32_roundnumbers, "test_packed_repeated_fixed32_roundnumbers");
+  DUMP_STATIC_ARRAY (uint32_0_max, "test_packed_repeated_fixed32_0_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_int64 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_int64, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int64_roundnumbers, "test_packed_repeated_int64_roundnumbers");
+  DUMP_STATIC_ARRAY (int64_min_max, "test_packed_repeated_int64_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_sint64 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_sint64, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int64_roundnumbers, "test_packed_repeated_sint64_roundnumbers");
+  DUMP_STATIC_ARRAY (int64_min_max, "test_packed_repeated_sint64_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_sfixed64 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_sfixed64, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (int64_roundnumbers, "test_packed_repeated_sfixed64_roundnumbers");
+  DUMP_STATIC_ARRAY (int64_min_max, "test_packed_repeated_sfixed64_min_max");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_uint64 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC (test_uint64, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY(uint64_roundnumbers, "test_packed_repeated_uint64_roundnumbers");
+  DUMP_STATIC_ARRAY(uint64_0_1_max, "test_packed_repeated_uint64_0_1_max");
+  DUMP_STATIC_ARRAY(uint64_random, "test_packed_repeated_uint64_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_fixed64 (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_fixed64, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY(uint64_roundnumbers, "test_packed_repeated_fixed64_roundnumbers");
+  DUMP_STATIC_ARRAY(uint64_0_1_max, "test_packed_repeated_fixed64_0_1_max");
+  DUMP_STATIC_ARRAY(uint64_random, "test_packed_repeated_fixed64_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_float (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_float, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY(float_random, "test_packed_repeated_float_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_double (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_double, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY(double_random, "test_packed_repeated_double_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_boolean (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC(test_boolean, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY(boolean_0, "test_packed_repeated_boolean_0");
+  DUMP_STATIC_ARRAY(boolean_1, "test_packed_repeated_boolean_1");
+  DUMP_STATIC_ARRAY(boolean_random, "test_packed_repeated_boolean_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+static void dump_test_packed_repeated_enum_small (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC (test_enum_small, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (enum_small_0, "test_packed_repeated_enum_small_0");
+  DUMP_STATIC_ARRAY (enum_small_1, "test_packed_repeated_enum_small_1");
+  DUMP_STATIC_ARRAY (enum_small_random, "test_packed_repeated_enum_small_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+
+static void dump_test_packed_repeated_enum (void)
+{
+#define DUMP_STATIC_ARRAY(static_array, output_array_name) \
+  DUMP_STATIC_ARRAY_GENERIC (test_enum, static_array, output_array_name)
+
+  DUMP_STATIC_ARRAY (enum_0, "test_packed_repeated_enum_0");
+  DUMP_STATIC_ARRAY (enum_1, "test_packed_repeated_enum_1");
+  DUMP_STATIC_ARRAY (enum_random, "test_packed_repeated_enum_random");
+
+#undef DUMP_STATIC_ARRAY
+}
+
 
 static void dump_test_unknown_fields (void)
 {
@@ -759,7 +931,7 @@ static void dump_test_unknown_fields (void)
   const google::protobuf::Message::Reflection *reflection = mess.GetReflection();
   google::protobuf::UnknownFieldSet *fs = reflection->MutableUnknownFields(&mess);
 
-#if PROTOC_VERSION >= 2001000
+#if GOOGLE_PROTOBUF_VERSION >= 2001000
   fs->AddVarint(5454, 255);
   fs->AddFixed32(5555, 260);
 #else
@@ -774,7 +946,7 @@ static void dump_test_unknown_fields (void)
 
   fs->Clear();
 
-#if PROTOC_VERSION >= 2001000
+#if GOOGLE_PROTOBUF_VERSION >= 2001000
   fs->AddLengthDelimited(6666, "xxxxxxxx");
   fs->AddFixed64(7777, 0x10101);
 #else
@@ -846,6 +1018,21 @@ int main()
   dump_test_repeated_string ();
   dump_test_repeated_bytes ();
   dump_test_repeated_SubMess ();
+  dump_test_packed_repeated_int32 ();
+  dump_test_packed_repeated_sint32 ();
+  dump_test_packed_repeated_uint32 ();
+  dump_test_packed_repeated_sfixed32 ();
+  dump_test_packed_repeated_fixed32 ();
+  dump_test_packed_repeated_int64 ();
+  dump_test_packed_repeated_sint64 ();
+  dump_test_packed_repeated_sfixed64 ();
+  dump_test_packed_repeated_uint64 ();
+  dump_test_packed_repeated_fixed64 ();
+  dump_test_packed_repeated_float ();
+  dump_test_packed_repeated_double ();
+  dump_test_packed_repeated_boolean ();
+  dump_test_packed_repeated_enum_small ();
+  dump_test_packed_repeated_enum ();
   dump_test_unknown_fields ();
   return 0;
 }
